@@ -1,7 +1,7 @@
 # -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf-8 -*-
 #
-# Copyright 2002 Ben Escoto <ben@emerose.org>
-# Copyright 2007 Kenneth Loafman <kenneth@loafman.com>
+# Copyright 2002 Ben Escoto
+# Copyright 2007 Kenneth Loafman
 #
 # This file is part of duplicity.
 #
@@ -46,7 +46,7 @@ class CommandlineTest(UnitTestCase):
         "remove_time": "100",
         "source_path": "foo/bar",
         "source_url": "file://duptest",
-        "target_dir": "foo/bar",
+        "target_path": "foo/bar",
         "target_url": "file://duptest",
     }
 
@@ -134,14 +134,14 @@ class CommandlineTest(UnitTestCase):
         for cmd in ["restore"] + cli_main.CommandAliases.restore:
             cli_main.process_command_line(f"{cmd} file://duptest foo/bar".split())
             self.assertEqual(config.action, "restore")
-            self.assertTrue(config.source_path.endswith("foo/bar"))
-            self.assertEqual(config.target_url, "file://duptest")
+            self.assertTrue(config.target_path.endswith("foo/bar"))
+            self.assertEqual(config.source_url, "file://duptest")
 
         for cmd in ["verify"] + cli_main.CommandAliases.verify:
             cli_main.process_command_line(f"{cmd} file://duptest foo/bar".split())
             self.assertEqual(config.action, "verify")
-            self.assertTrue(config.source_path.endswith("foo/bar"))
-            self.assertEqual(config.target_url, "file://duptest")
+            self.assertTrue(config.target_path.endswith("foo/bar"))
+            self.assertEqual(config.source_url, "file://duptest")
 
     @pytest.mark.usefixtures("redirect_stdin")
     def test_full_command_errors_reversed_args(self):
@@ -151,7 +151,7 @@ class CommandlineTest(UnitTestCase):
         new_args = {
             "source_path": "file://duptest",
             "source_url": "foo/bar",
-            "target_dir": "file://duptest",
+            "target_path": "file://duptest",
             "target_url": "foo/bar",
         }
         err_msg = "should be url|should be pathname"
@@ -238,31 +238,6 @@ class CommandlineTest(UnitTestCase):
             cli_main.process_command_line(cline)
             self.assertEqual(config.gpg_profile.sign_key, key)
 
-    @pytest.mark.usefixtures("redirect_stdin")
-    def test_bad_encryption_options(self):
-        """
-        test short option aliases
-        """
-        start = "inc foo/bar file:///target_url "
-        keys = (
-            "DEADFOO",
-            "DEADDEADDEADFOO",
-            "DEADDEADDEADDEADDEADDEADDEADDEADDEADFOO",
-        )
-
-        for key in keys:
-            with self.assertRaises(CommandLineError) as cm:
-                cline = f"{start} --encrypt-key={key}".split()
-                cli_main.process_command_line(cline)
-
-            with self.assertRaises(CommandLineError) as cm:
-                cline = f"{start} --hidden-encrypt-key={key}".split()
-                cli_main.process_command_line(cline)
-
-            with self.assertRaises(CommandLineError) as cm:
-                cline = f"{start} --sign-key={key}".split()
-                cli_main.process_command_line(cline)
-
     @pytest.mark.usefixtures("redirect_stdin")
     def test_implied_commands(self):
         """
@@ -278,7 +253,7 @@ class CommandlineTest(UnitTestCase):
         cli_main.process_command_line(cline)
         self.assertEqual(config.action, "restore")
         self.assertEqual(config.source_url, "file:///source_url")
-        self.assertEqual(config.target_dir, "foo/bar")
+        self.assertEqual(config.target_path, "foo/bar")
 
         cline = "-v9 foo/bar file:///target_url".split()
         cli_main.process_command_line(cline)
@@ -290,7 +265,7 @@ class CommandlineTest(UnitTestCase):
         cli_main.process_command_line(cline)
         self.assertEqual(config.action, "restore")
         self.assertEqual(config.source_url, "file:///source_url")
-        self.assertEqual(config.target_dir, "foo/bar")
+        self.assertEqual(config.target_path, "foo/bar")
 
         cline = "foo/bar -v9 file:///target_url".split()
         cli_main.process_command_line(cline)
@@ -302,7 +277,7 @@ class CommandlineTest(UnitTestCase):
         cli_main.process_command_line(cline)
         self.assertEqual(config.action, "restore")
         self.assertEqual(config.source_url, "file:///source_url")
-        self.assertEqual(config.target_dir, "foo/bar")
+        self.assertEqual(config.target_path, "foo/bar")
 
         cline = "--verbosity n foo/bar file:///target_url".split()
         cli_main.process_command_line(cline)
@@ -314,7 +289,7 @@ class CommandlineTest(UnitTestCase):
         cli_main.process_command_line(cline)
         self.assertEqual(config.action, "restore")
         self.assertEqual(config.source_url, "file:///source_url")
-        self.assertEqual(config.target_dir, "foo/bar")
+        self.assertEqual(config.target_path, "foo/bar")
 
         cline = "foo/bar --verbosity n file:///target_url".split()
         cli_main.process_command_line(cline)
@@ -326,7 +301,7 @@ class CommandlineTest(UnitTestCase):
         cli_main.process_command_line(cline)
         self.assertEqual(config.action, "restore")
         self.assertEqual(config.source_url, "file:///source_url")
-        self.assertEqual(config.target_dir, "foo/bar")
+        self.assertEqual(config.target_path, "foo/bar")
 
         # this incremental misses the path argument
         with self.assertRaises(CommandLineError) as cm:
@@ -575,3 +550,34 @@ class CommandlineTest(UnitTestCase):
         cline = shlex.split("backup --gpg-options='--homedir=/home/user' foo/bar file://target_url")
         cli_main.process_command_line(cline)
         self.assertEqual(config.gpg_options, "--homedir=/home/user")
+
+        # Issue 869 - accept time formats as well as intervals as arguments to --full-if-older-than
+        cline = shlex.split("backup --full-if-older-than now foo/bar file://target_url")
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.full_if_older_than, 0)
+
+        cline = shlex.split("backup --full-if-older-than 1D foo/bar file://target_url")
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.full_if_older_than, 86400)
+
+        dup_time.setcurtime()
+
+        cline = shlex.split("backup --full-if-older-than 2025-05-05T00:00:00Z foo/bar file://target_url")
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.full_if_older_than, dup_time.curtime - 1746403200)
+
+        cline = shlex.split("backup --full-if-older-than 2025-05-05T00:00:00+00:00 foo/bar file://target_url")
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.full_if_older_than, dup_time.curtime - 1746403200)
+
+        cline = shlex.split("backup --full-if-older-than 2025-05-05T00:00:00 foo/bar file://target_url")
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.full_if_older_than, dup_time.curtime - 1746403200)
+
+        cline = shlex.split("backup --full-if-older-than 2025-05-05 foo/bar file://target_url")
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.full_if_older_than, dup_time.curtime - 1746403200)
+
+        cline = shlex.split("backup --full-if-older-than 1746403200 foo/bar file://target_url")
+        cli_main.process_command_line(cline)
+        self.assertEqual(config.full_if_older_than, dup_time.curtime - 1746403200)
